Applications
============

Mountable ASGI application types.

AsgiApplication
---------------

Base class for all genro-asgi applications.

.. automodule:: genro_asgi.applications.asgi_application
   :members:
   :undoc-members:
   :show-inheritance:

McpApplication
--------------

MCP Streamable HTTP transport application.

.. automodule:: genro_asgi.applications.mcp_application
   :members:
   :undoc-members:
   :show-inheritance:
